# Project Guarani

This library provides an implementation for asynchronous
authentication and authorization of web applications.
It provides support for OAuth 2.1 and OpenID Connect.

For more details, please visit the documentation.

Any doubts and suggestions can be sent to my [email](mailto:eduardorbr7@gmail.com).
Just prepend the title with `#Guarani#`, and I will try my best to answer.

## Supported Protocols and RFCs

-   OAuth 2.1

    -   [OAuth 2.1 Draft](https://tools.ietf.org/html/draft-parecki-oauth-v2-1)
    -   [RFC 7009: Token Revocation](https://tools.ietf.org/html/rfc7009)

-   OpenID Connect
    -   [OpenID Connect Core 1.0](https://openid.net/specs/openid-connect-core-1_0.html)

# License

This project is licensed under the MIT License.
For more details, please refer to the `LICENSE` file.
